==> deepin-camera_1.1.2.orig.tar.xz: deepin-camera-1.1.2/src/translations/deepin-camera_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>La grabación esta en progreso. ¿Quiere cerrar la ventana?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>No tiene permisos para modificar esta carpeta</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Carpeta inválida</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Ubicación del archivo</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Capturar</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Modo ráfaga</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Ajustes de temporizador</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Salida</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Formato de salida</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 piezas</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 piezas</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Cámara de Deepin captura imágenes y vídeos con la cámara de su equipo o cámara web.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>No se guardo el archivo</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Guardar en:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Ajustes de resolución</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Resolución:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotos:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Vídeos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efectos sonoros</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Detener grabación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Detener captura</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menú contextual</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Tomar foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Grabar vídeo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Detener captura</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>No se encontró cámara web</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>La cámara web está en uso</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Detener grabación</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.3.7.1.orig.tar.xz: deepin-camera-1.3.7.1/src/translations/deepin-camera_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Grabación en progreso. ¿Desea cerrar la ventana?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Abrir carpeta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Foto</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Cambiar de cámara</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>No tiene permisos para modificar esta carpeta</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Carpeta no válida</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Básico</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Ubicación del archivo</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Capturar</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Modo ráfaga</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Ajustes de temporizador</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Salida</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Formato de salida</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 piezas</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 piezas</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Cámara de Deepin captura imágenes y vídeos con la cámara de su equipo o cámara web.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Archivo no guardado</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Guardar en:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Foto:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Ajustes de resolución</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Resolución:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotos:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Vídeos:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Efectos sonoros</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Modo espejo</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Linterna</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Cámara</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Detener grabación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimir</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Detener captura</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Menú contextual</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Tomar foto</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Grabar vídeo</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Detener captura</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Vívido</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Cálido</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Frío</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Película</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gris</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;N</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Linterna</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Encendido</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Apagado</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Retraso en la captura</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtros</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Exposición</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>No se encontró cámara web</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>La cámara web está en uso</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Detener grabación</translation>
    </message>
</context>
</TS>
